Changelog
=========


0.3.1 (2024-08-26)
------------------

- Symlink correction.
  [sgeulette]

0.3.0 (2024-08-26)
------------------

- Added symlinked client folder to ease search and verification.
  [sgeulette]
- Enclosed all treatment in try except to send notification when an error occurs.
  [sgeulette]
- Included hostname in filename for customer with multiple pcs.
  [sgeulette]
- Added client version in email and log
  [sgeulette]

0.2.1 (2024-08-14)
------------------

- Added hostname in mail info and log.
  [sgeulette]

0.2.0 (2024-08-14)
------------------

- Send email only if given level is ERROR.
  [sgeulette]

0.1.0 (2024-08-14)
------------------

- Initial release with @message-receiver endpoint.
  [sgeulette]
